@@ -1,5 +1,5 @@
 # TODO: Add comment
-# 
+#
 # Author: srazbash
 ###############################################################################
 
@@ -11,22 +11,22 @@ checkAdmissibility<-function(opt.env, box.cox=NULL, small.phi=NULL, ar.coefs=NUL
 			return(FALSE)
 		}
 	}
-	
+
 	#Check the range of small.phi
 	if(!is.null(small.phi)) {
 		if(((small.phi < .8) | (small.phi > 1))) {
 			#print("small-phi")
 			return(FALSE)
 		}
-	
+
 	}
-	
+
 	#Check AR part for stationarity
 	if(!is.null(ar.coefs)) {
 		#print("as.coefs")
 		arCheck <- function(ar) {
 			p <- max(which(c(1, -ar) != 0)) - 1
-			if (!p) 
+			if (!p)
 				return(TRUE)
 			all(Mod(polyroot(c(1, -ar[1L:p]))) > 1)
 		}
@@ -35,20 +35,20 @@ checkAdmissibility<-function(opt.env, box.cox=NULL, small.phi=NULL, ar.coefs=NUL
 			return(FALSE)
 		}
 	}
-	
+
 	#Check MA part for invetibility
 	if(!is.null(ma.coefs)) {
 		#print("ma.coefs")
 		maInvert <- function(ma) {
 			q <- length(ma)
 			q0 <- max(which(c(1, ma) != 0)) - 1L
-			if (!q0) 
+			if (!q0)
 				return(ma)
 			roots <- polyroot(c(1, ma[1L:q0]))
 			ind <- Mod(roots) < 1
-			if (all(!ind)) 
+			if (all(!ind))
 				return(ma)
-			if (q0 == 1) 
+			if (q0 == 1)
 				return(c(1/ma[1L], rep(0, q - q0)))
 			roots[ind] <- 1/roots[ind]
 			x <- 1
@@ -61,11 +61,11 @@ checkAdmissibility<-function(opt.env, box.cox=NULL, small.phi=NULL, ar.coefs=NUL
 			return(FALSE)
 		}
 	}
-	
+
 	#Check the eigen values of the D matrix
-	D.eigen.values<-eigen(opt.env$D, symmetric=FALSE, only.values=TRUE, EISPACK=TRUE)$values
-	
+	D.eigen.values<-eigen(opt.env$D, symmetric=FALSE, only.values=TRUE)$values
+
 	return(all(abs(D.eigen.values) < 1+1e-10))
-	
-	
+
+
 }
