@@ -1,6 +1,11 @@
 getResponse <- function(object,...) UseMethod("getResponse")
 
-getResponse.default <- function(object,...){object$x}
+getResponse.default <- function(object,...){
+	if(is.list(object))
+		return(object$x)
+	else
+		return(NULL)
+}
 
 getResponse.lm <- function(object,...) {
 	responsevar <- as.character(formula(object$model))[2]
@@ -17,7 +22,11 @@ getResponse.Arima <- function(object,...) {
     	if(is.null(series.name))
     		stop("missing component series in Arima model")
     	else
-	    	x <- eval.parent(parse(text = series.name))
+    	{
+	    	x <- try(eval.parent(parse(text = series.name)),silent=TRUE)
+	    	if(class(x)=="try-error") # Try one level further up the chain
+	    		x <- eval.parent(parse(text = series.name),2)
+    	}
 	}
 	if(is.null(tsp(x)))
 		x <- ts(x,frequency=1,start=1)
